#
# spec file for package kpackage
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%define qt5_version 5.15.2
%bcond_without released
Name:           kpackage
Version:        5.116.0
Release:        1.5
Summary:        Non-binary asset user-installable package managing framework
License:        GPL-2.0-or-later AND LGPL-2.0-or-later
URL:            https://www.kde.org
Source:         %{name}-%{version}.tar.xz
%if %{with released}
Source1:        %{name}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  extra-cmake-modules >= %{_kf5_version}
BuildRequires:  fdupes
BuildRequires:  cmake(KF5Archive) >= %{_kf5_version}
BuildRequires:  cmake(KF5CoreAddons) >= %{_kf5_version}
BuildRequires:  cmake(KF5DocTools) >= %{_kf5_version}
BuildRequires:  cmake(KF5I18n) >= %{_kf5_version}
BuildRequires:  cmake(Qt5Core) >= %{qt5_version}
BuildRequires:  cmake(Qt5DBus) >= %{qt5_version}
BuildRequires:  cmake(Qt5Test) >= %{qt5_version}

%description
This framework lets applications to manage user installable packages of non-binary assets.

%package devel
Summary:        Non-binary asset user-installable package managing framework
Requires:       %{name} = %{version}
Requires:       cmake(KF5CoreAddons) >= %{_kf5_version}

%description devel
This framework lets applications to manage user installable packages of non-binary assets.
Development files.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf5 -d build -- -DSYSCONF_INSTALL_DIR=%{_kf5_sysconfdir}
%cmake_build

%install
%kf5_makeinstall -C build

%find_lang %{name} --with-man --all-name

%ldconfig_scriptlets

%files lang -f %{name}.lang

%files
%license LICENSES/*
%doc README*
%dir %{_kf5_servicetypesdir}
%doc %lang(en) %{_kf5_mandir}/*/kpackagetool*
%{_kf5_bindir}/kpackagetool*
%{_kf5_debugdir}/*.categories
%{_kf5_debugdir}/*.renamecategories
%{_kf5_libdir}/libKF5Package.so.*
%{_kf5_servicetypesdir}/kpackage-generic.desktop
%{_kf5_servicetypesdir}/kpackage-genericqml.desktop
%{_kf5_servicetypesdir}/kpackage-packagestructure.desktop

%files devel
%{_kf5_includedir}/
%{_kf5_libdir}/cmake/KF5Package/
%{_kf5_libdir}/libKF5Package.so

%changelog
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.116.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.116.0
- Changes since 5.115.0:
  * testpackage: Add a website so that the tests succeed
* Thu Feb  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.115.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.115.0
- No code change since 5.114.0
* Sat Jan 13 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.114.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.114.0
- No code change since 5.113.0
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.113.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.113.0
- No code change since 5.112.0
* Mon Nov  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.112.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.112.0
- No code change since 5.111.0
* Mon Oct  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.111.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.111.0
- No code change since 5.110.0
* Wed Sep  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.110.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.110.0
- No code change since 5.109.0
* Tue Aug  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.109.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.109.0
- Changes since 5.108.0:
  * KPackageTool: Show deprecation warning when metadata.desktop file is used
  * Add explicit moc includes to sources for moc-covered headers
* Mon Jul  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.108.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.108.0
- Changes since 5.107.0:
  * Remove qt6 CI builds
  * Define json-validate-ignore property in .kde-ci.yml
* Mon Jun  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.107.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.107.0
- No code change since 5.106.0
* Sat May  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.106.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.106.0
- Changes since 5.105.0:
  * Deprecate KPackage::Package::name, add default for parameters
* Sat Apr  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.105.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.105.0
- No code change since 5.104.0
* Mon Mar  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.104.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.104.0
- Changes since 5.103.0:
  * Check pluginId contains '/' before using it as package type (kde#449727)
* Wed Feb  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.103.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.103.0
- Changes since 5.102.0:
  * Update README with new json metadata
  * Show deprecation message about the desktop to json conversion being removed
* Thu Jan 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.102.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.102.0
- No code change since 5.101.0
* Tue Dec  6 2022 Christophe Marin <christophe@krop.fr>
- Update to 5.101.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.101.0
- No code change since 5.100.0
* Tue Nov  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.100.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.100.0
- Changes since 5.99.0:
  * Add Qt6 windows CI support
* Sat Oct  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.99.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.99.0
- Changes since 5.98.0:
  * .gitlab-ci.yml: enable static builds
  * Build test KPackage structure as static plugin
  * Copy required plasmoid kpackage definition sin autotests to avoid issues when building statically
  * Fix duplicate symbol in static builds (kde#459099)
  * Ignore sddmtheme dependencies if we do not have the knsrc file installed (kde#415583)
  * Remove unneeded known categories
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.98.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.98.0
- Changes since 5.97.0:
  * Add FreeBSD Qt6 CI support
* Sun Aug  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.97.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.97.0
- Changes since 5.96.0:
  * Fix listing of KPackage structures (kde#456726)
  * README.md add dot at end of sentence
  * Port archive of test plasmoid to json metadata
  * Fix tests that generate metadata.desktop file for Qt6 build
  * Port metadata files in autotests to json
* Sun Jul  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.96.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.96.0
- No code change since 5.95.0
* Fri Jun 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.95.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.95.0
- Changes since 5.94.0:
  * port to standard C++ smart pointers where possible
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.94.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.94.0
- Changes since 5.93.0:
  * Require unit tests to pass on CI
  * Remove CMAKE_AUTOMOC_RELAXED_MODE
  * Fix build with deprecation version 5.92 or above
  * Add windows CI
* Sun Apr  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.93.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.93.0
- Changes since 5.92.0:
  * PackageJobThread: Also check if metadata.json file exists
  * Explicitly call KPluginMetaData::fromJsonFile when constructing metadata objects
  * Fix desktoptojson invocation when cross-compiling
* Mon Mar  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.92.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.92.0
- No code change since 5.91.0
* Sun Feb  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.91.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.91.0
- Changes since 5.90.0:
  * Simplify code using KPluginMetaData::fromJsonFile
  * Explicitly call KPluginMetaData::fromJsonFile when constructing metadata objects
  * Fix unintended result in readKPackageTypes (kde#448625)
  * Use ecm_mark_nongui_executable() for mock:// handler
  * PackageJob: Use QStandardPaths::findExecutable() to find resolvers
  * QueryTest: validate the install() result
  * Add CI qt6 support
  * Build static libs which are linked into shared libs as PIC
* Mon Jan  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.90.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.90.0
- Changes since 5.89.0:
  * PackagePrivate: use unique_ptr for fallbackPackage
  * Add a service type property definition for NoDisplay
  * Fix macro. We need to use specific rcc program
  * Fix compile against qt6
  * Change build system for building against qt6
  * Port away from KPluginMetaData::serviceTypes
* Sat Dec  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.89.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.89.0
- Changes since 5.88.0:
  * Utilize type-safe KPluginMetaData API methods
  * Utilize KPluginMetaData::value overloads
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Strip 'Source' URL for faster submissions
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.88.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.88.0
- Changes since 5.87.0:
  * Allow KCM kpackages to use metadata of C++ plugin
  * Utilize std::optional to check if we have already searched for a
    KPluginMetaData object
  * KPackage: Copy KPluginMetaData object when copying d-ptr
  * Add FreeBSD CI
* Sun Oct  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.87.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.87.0
- Changes since 5.86.0:
  * Add Gitlab CI configuration
* Wed Sep 15 2021 Christophe Giboudeaux <christophe@krop.fr>
- Drop the unneeded baselibs.conf.
* Mon Sep  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.86.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.86.0
- Changes since 5.85.0:
  * Port away from deprecated KPluginLoader
  * Deprecate unused virtual functions in PackageLoader
  * Try loading package structures by name
  * kpackagetool: Fix small typo in its output
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.85.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.85.0
- Changes since 5.84.0:
  * Deprecate kpackage_install_bundled_package cmake function
  * Clean up leftovers from index generation
  * Reduce severity of warnings about appstream generations
  * Remove unused PackageLoaderPrivate::parentAppConstraint method
  * Deprecate implicitly  defining X-KDE-ParentApp by parent structure
  * Introduce new KPackageStructure property to identify plugins & packages
  * autotests: Organize package structures into subdir
  * autotests: Avoid compiling the same files 5 times
  * Include a warning when setting the path without a structure
* Sun Jul  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.84.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.84.0
- Changes since 5.83.0:
  * Simplify plugin loading
  * KF5PackageMacros: Only include ECM manually if config vars are missing
  * Remove unused includes
  * Deprecate kpackage/version.h header
  * Prefer K_PLUGIN_CLASS_WITH_JSON macro in README code snippet
  * PackageStructure: Remove unneeded version export
  * KF5PackageMacros: Install JSON metadata file if it exists in source
- Only install the license files once
* Sat Jun  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.83.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.83.0
- Changes since 5.82.0:
  * Bump required CMake version to 3.16
  * Call ki18n_install() unconditionally
* Sat May  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.82.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.82.0
- Changes since 5.81.0:
  * Remove kpluginindex.json caching
* Mon Apr  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.81.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.81.0
- No code change since 5.80.0
* Sun Mar  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.80.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.80.0
- Changes since 5.79.0:
  * Run clang-format
  * Add clang-format configuration
* Mon Feb  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.79.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.79.0
- Changes since 5.78.0:
  * Add missing includes
  * Document PackageStructure ownership when using PackageLoader
* Wed Jan  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.78.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.78.0
- Changes since 5.77.0:
  * autotests: attempt to fix them on Windows, or at least expect failures
  * autotests: clarify very confusing test. The expected value is actually empty.
* Sat Dec  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.77.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.77.0
- Changes since 5.76.0:
  * Drop X-KDE-PluginInfo-Depends
* Sat Nov  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.76.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.76.0
- Changes since 5.75.0:
  * Fix build errors if PREFIX is different from ECM's PREFIX.
  * Make "no metadata" warning a debug-only thing
  * If include is define in .h remove it if it's defined in .cpp too (scripted)
  * Documentation fixes: Use more entities and some punctuation
* Mon Oct  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.75.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.75.0
- Changes since 5.74.0:
  * Fix DBus notifications when installed/updated
  * Remove obsolete license text
  * Relicense file to LGPL-2.0-or-later
  * initialize pointer, constify pointer
* Sun Sep  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.74.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.74.0
- Changes since 5.73.0:
  * Remove obsolete COPYING files
  * Do not delete package root if package was deleted (kde#410682)
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.73.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.73.0
- Changes since 5.72.0:
  * Use KF-standardized Qt logging categories
  * Use camelcase include. (scripted)
* Sun Jul  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.72.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.72.0
- Changes since 5.71.0:
  * Convert license to GPL-2.0-or-later
- Fix the license tag. the kpackagetool executable is GPL-2.0-or-later
* Sun Jun  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.71.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.71.0
- No code change since 5.70.0
* Sun May  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.70.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.70.0
- Changes since 5.69.0:
  * Fix testpackage-appstream: XDG_DATA_DIRS needs to be explicitly extended
* Sun Apr  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.69.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.69.0
- No code change since 5.68.0
* Sun Mar  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.68.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.68.0.php
- Changes since 5.67.0:
  * Use ecm_qt_install_logging_categories over manual categories file
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.67.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.67.0.php
- No code change since 5.66.0
* Sun Jan  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.66.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.66.0.php
- Changes since 5.65.0:
  * Port endl to "\n"
  * Port QRegExp to QRegularExpression
  * Update the obsolete projects.kde.org URL
* Sun Dec  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.65.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.65.0.php
- Changes since 5.64.0:
  * Remove -std=c++0x flag and duplicated -Wall flag
  * Remove commented cmake code
  * support Qt File selectors in KPackage
* Sun Nov  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.64.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.64.0.php
- Changes since 5.63.0:
  * Use ECMGenerateExportHeader to manage deprecated API better
* Sun Oct  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.63.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.63.0.php
- No code change since 5.62.0
* Sat Sep  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.62.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.62.0.php
- Changes since 5.61.0:
  * Remove unused includes
- Replace foo-devel with cmake(KF5Foo) in build requirements
* Wed Aug  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.61.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.61.0.php
- Changes since 5.60.0:
  * Offer metadata.json when requesting the package metadata
  * PackageLoader: Use the right scope for the KCompressionDevice
  * Use metadata.json when creating the metadata from KPackage::metadata()
  * Fix build due to missing QVector include
* Fri Jul 19 2019 Wolfgang Bauer <wbauer@tmo.at>
- Don't lower minimum Qt version anymore, it requires 5.11 now
* Sun Jul 14 2019 lbeltrame@kde.org
- Update to 5.60.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.60.0.php
- Changes since 5.59.0:
  * performance, Qt API
  * Install in new logging directory when we use kf5 5.59.0
* Sun Jun  9 2019 lbeltrame@kde.org
- Update to 5.59.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.59.0.php
- No code changes since 5.58.0
* Wed May 15 2019 lbeltrame@kde.org
- Update to 5.58.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.58.0.php
- Changes since 5.57.0:
  * Add missing properties in kpackage-generic.desktop
  * kpackagetool: read kpackage-generic.desktop from qrc
  * AppStream generation: make sure we look up for the package structure on packages that have metadata.desktop/json too
  * autotests: don't fail appstream test because of anything on stderr
  * autotests: display command being executed, to help debugging failures
  * autotests: make output nicer
  * Don't use qAsConst over a temporary variable
- Dropped patches, now upstream:
  * Dont-use-qAsConst-over-a-temporary-variable.patch
* Tue Apr 16 2019 wbauer@tmo.at
- Add Dont-use-qAsConst-over-a-temporary-variable.patch to fix a
  possible crash
* Sun Apr 14 2019 lbeltrame@kde.org
- Update to 5.57.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.57.0.php
- Changes since 5.56.0:
  * Fix finding the host tools targets file in the Android docker environment
  * [kpackages] compile without foreach
  * Add cross-compilation support for kpackagetool5
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * It compiles fine with qt5.13
  * extend documentation of kpackage_install_bundled_package
  * remove kpackage_install_package deprecation warning
* Fri Feb 15 2019 alarrosa@suse.com
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * Remove unused found member
  * Make translations work
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * Fix typo in i18n message (cmdline option description)
* Sat Dec 15 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summaries.
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * Use isEmpty
  * Don't generate appstream data for files that lack a description (kde#400431)
  * Capture package metadata before install start
  * It compiles without deprecated method
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * Capture package metadata before install start
  * Use new categories
  * Call reserve() on Qt containers if fill size is known before
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * Use reference in for loop for type with non-trivial copy constructor
  * Move Qt5::DBus to the 'PRIVATE' link targets
  * Fix compile with strict compiler flags
  * Emit signals when a package is installed/uninstalled
  * Fix minor EBN issues
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * autotests: plasmoidpackagetest fails when run in parallel to others
  * autotests: handle /home being a symlink on the FreeBSD CI
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * Honor BUILD_TESTING
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * Remove QT definitions duplicated from KDEFrameworkCompilerSettings or dead
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * kpackage_install_*package: fix missing dep between .desktop and .json
  * make sure paths in rcc are never derived from absolute paths
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * Use override
  * Add missing explicit
  * use KDE_INSTALL_DATADIR instead of FULL_DATADIR
  * Warning--
  * Add donate urls to test data
  * Add override
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * Try to fix the FreeBSD build.
  * Use Qt5::rcc instead of looking for the executable.
  * Use NO_DEFAULT_PATH to ensure the right command is picked up
  * Look also for prefixed rcc executables
  * set component for correct qrc generation
  * regenerate qrc on every build
  * Don't create dependency loop
  * Fix the rcc binary package generation
  * set(component ${component})
  * Fix rcc packages generation
  * Generate the rcc file every time, at install time
  * Use ecm_setup_qtplugin_macro_names
  * remove the rcc before generating
  * Make org.kde. components include a donate URL
  * Remove not necessary QtCore and co
  * Mark kpackage_install_package undeprecated for plasma_install_package
  * autotest: improve error reporting on failure
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * Help automoc to find metadata JSON files referenced in the code
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * None
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Remove obsolete reviewboardrc file
  * Fix typo
  * Prevent cmake 3.10+ warning with moc & K_EXPORT_KPACKAGE_PACKAGE_WITH_JSON
  * invalidate the runtime cache on install
  * adjust relative directory
  * use configure_file instead of install
  * use QByteArrayLiteral
  * create the needed directory
  * experimental support for rcc files loading in kpackage
  * Use qCDebug
  * compile against Qt 5.7
  * Fix up package indexing and add runtime caching
  * new KPackage::fileUrl() method
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * Fix trivial clazy warnings
  * Properly do strings in the kpackage framework
  * Don't try to generate metadata.json if there's no metadata.desktop
  * fix kpluginindex caching
  * Improve error output
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * use the non installed service files
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * kpackage: bundle a copy of servicetypes/kpackage-generic.desktop
  * kpackagetool: bundle a copy of servicetypes/kpackage-generic.desktop
  * autotest: adapt for ECM 5.38 setting CMAKE_RUNTIME_OUTPUT_DIRECTORY to bin
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * refactor kpackagetool away from stringy options
  * autotests: fix running tests in parallel
  * kpackagetool: fix memory leak detected by LeakSanitizer
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * kpackagetool can now write appstream data to a file
  * assert the testpackage appstream data validates
  * adopt new KAboutLicense::spdx
  * do not stderr that NoDisplay is set
  * API dox: use @param for normal parameter listing, not @arg
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * Added kpackage-genericqml.desktop
  * tests: forgot to use LINK_LIBRARIES for ecm_add_test
  * cmake: use ecm_add_test more
  * [FEATURE] Option to build & install QCH file with the public API dox
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * API dox: NULL pointer -> null pointer
  * API dox: Use doxygen notation to have comments used
  * API dox: note CamelCase includes by @class tag with more classes
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * Fix spelling in documentation.
  * fix include path in KF5PackageMacros.cmake https://phabricator.kde.org/D5615
  * Ignore warnings during appdata generation (kde#378529)
- Remove patches, now upstream:
  * 0001-Ignore-warnings-during-appdata-generation.patch
- Use %%find_lang --with-man --all-name
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * build autotests as regular executables
  * Upgrade KF5 version to 5.33.0.
* Fri Apr  7 2017 fabian@ritter-vogt.de
- Add patch to allow appdata installation even with warnings:
  * 0001-Ignore-warnings-during-appdata-generation.patch
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Commit translations from l10n-kf5
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * finish support for opening compressed packages
  * Upgrade KF5 version to 5.32.0.
  * Upgrade Qt5 version requirement to 5.6.0.
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Thu Jan 19 2017 fabian@ritter-vogt.de
- Update to 5.30.0
  * [PackageLoader] Don't access invalid KPluginMetadata (bug 374541)
  * fix description for option -t in man page
  * Improve error message
  * Fix the help message for --type
  * Improve installation process of KPackage bundles
  * Install a kpackage-generic.desktop file
  * Exclude qmlc files from installation
  * Don't list separately plasmoids from metadata.desktop and .json
* Wed Dec 14 2016 hrvoje.senjan@gmail.com
- Update to 5.29.1
  * Fix cmake failure when two packages with different type have same id
  * Additional fix for packages with different types but same ids
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * Keep installing metadata.desktop (kde#372594)
  * Manually load metadata if absolute path is passed
  * Fix potential failure if package is not appstream compatible
  * Let KPackage know about X-Plasma-RootPath
  * Fix generating the metadata.json file
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Sun Nov 20 2016 hrvoje.senjan@gmail.com
- Hotfix 5.28.1
  * Keep installing metadata.desktop (kde#372594)
- Drop upstreamed 0001-keep-installing-metadata-desktop.patch
* Fri Nov 18 2016 alarrosa@suse.com
- Add 0001-keep-installing-metadata-desktop.patch to keep installing
  metadata.desktop (kde#372594)
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * Make sure we're looking both for json and desktop metadata
  * Guard against Q_GLOBAL_STATIC being destroyed at app shutdown
  * Fix dangling pointer in KPackageJob (kde#369935)
  * Remove discovery associated to a key when removing a definition
  * Generate the icon into the appstream file
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
- Drop upstreamed fix-package-remove-definition.diff
* Sun Oct  9 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * Don't generate appstream files for components that are not in rdn
  * Make kpackage_install_package work with KDE_INSTALL_DIRS_NO_DEPRECATED
  * Remove unused var KPACKAGE_DATA_INSTALL_DIR
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
* Fri Oct  7 2016 alarrosa@suse.com
- Add fix-package-remove-definition.diff:
  Removes package discoveries too when removing a definition, so
  old data is not kept forever around.
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * Silence contentHash deprecation warnings
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * Infer the ParentApp from the PackageStructure plugin
  * Let kpackagetool5 generate appstream information for kpackage components
  * Make it possible to load metadata.json file from kpackagetool5
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * After installing a package, load it
  * If the package exists and up to date don't fail
  * Add Package::cryptographicHash(QCryptographicHash::Algorithm)
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * Let KDocTools stay optional on KPackage
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * Avoid finding the same package multiple times from different paths
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * Make it possible to provide the metadata in json
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
* Thu Dec 10 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * kpackagetool can uninstall a package from a package file
  * kpackagetool is now smarter about finding the right servicetype
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * The Qt version requirement has been bumped from 5.2 to 5.3
  * Debug output has been ported to categorized output, for less
    noise by default
  * Docbook documentation has been reviewed and updated
  * Make the subtitles, subtitles ;)
  * kpackagetool: Fix output of non-latin text to stdout
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
* Sun Jul  5 2015 hrvoje.senjan@gmail.com
- Update to 5.12.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.12.0.php
* Sun Jun  7 2015 hrvoje.senjan@gmail.com
- Update to 5.11.0
  * Guard the structure qpointer access (kde#347231)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.11.0.php
* Sun May  3 2015 hrvoje.senjan@gmail.com
- Update to 5.10.0
  * Add a KPackage::findPackages function similar to
    KPluginLoader::findPlugins
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.10.0.php
* Sat Apr  4 2015 hrvoje.senjan@gmail.com
- Update to 5.9.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.9.0.php
* Sat Mar  7 2015 hrvoje.senjan@gmail.com
- Update to 5.8.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.8.0.php
* Sun Feb  8 2015 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * Renamed kpackagetool man to kpackagetool5
  * Fixed installation on case-insensitive filesystems
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.7.0.php
* Sat Jan  3 2015 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.6.0.php
* Fri Sep 19 2014 hrvoje.senjan@gmail.com
- Activate kpackage-framework package
